@@ -31,7 +31,7 @@ class HTTP:
     Pointer, go to http://tools.ietf.org/html/draft-pbryan-zyp-json-pointer-00.
     """
 
-    ROBOT_LIBRARY_VERSION = "0.3.1"
+    ROBOT_LIBRARY_VERSION = "0.3.2"
 
     class Context(object):
         def __init__(self, http, host=None):
@@ -196,7 +196,7 @@ class HTTP:
         self.context.pre_process_request()
         logger.debug("Performing HEAD request on http://%s%s" % (self.app.host, url,))
         self.context.post_process_request(
-          self.app.head(path, {}, self.context.request_headers)
+          self.app.head(path, self.context.request_headers)
         )
 
     def GET(self, url):
@@ -300,6 +300,20 @@ class HTTP:
 
     # status code
 
+    def get_response_status(self):
+        """
+        Returns the response status line (e.g. "200 OK" or "404 Not found")
+
+        Notice, this is not the response status code (e.g. 200), but the entire
+        first line of the response. To check for a status code, use the
+        following:
+
+        Example:
+        | ${status}=        | Get Response Status |           |
+        | Should Start With | 200                 | ${status} |
+        """
+        return self.response.status
+
     def response_status_code_should_equal(self, status_code):
         """
         Fails if the response status code of the previous request was not the
@@ -339,9 +353,12 @@ class HTTP:
     def get_response_header(self, header_name):
         """
         Get the response header with the name `header_name`
+
+        If there are two headers with the same key, the return value of this
+        keyword is a list containing both values.
         """
         self.response_should_have_header(header_name)
-        return self.response.headers[header_name]
+        return self.response.headers.getall(header_name)
 
     def response_header_should_equal(self, header_name, expected):
         """
